.. Hiperwalk documentation master file, created by
   sphinx-quickstart on Wed May 11 11:03:45 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Hiperwalk!
=====================

**Hiperwalk** (High-performance Quantum Walk Simulator) is a freeware open-source program that
allows the user to perform simulations of quantum walks on graphs using HPC.
The user can use the parallel resources of the computer,
such as accelerator cards, multicore CPU and GPGPU to
speedup the overall process without knowing parallel programming.
It is under development and employs C, Python, and OpenCL.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   install/index
   tutorial/index
   documentation/index
   development/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
